@@ -254,7 +254,8 @@ class Dump(object):
             if v is not NO_VALUE_MARKER:
                 # found a value or default schema value
                 if hasattr(v, 'dump'):
-                    # dump MongoSubItem, MongoItemsData or MongoListData
+                    # dump MongoSubItem, MongoDubObject, MongoItemsData or
+                    # MongoListData
                     data[k] = v.dump()
                 else:
                     # store simple value including None if None is given
@@ -413,6 +414,70 @@ class SecureMongoItemBase(MongoItemBase):
         super(SecureMongoItemBase, self).__init__(data)
 
 
+class MongoSubObjectBase(MongoParentAware, SetupConvertDump):
+    """Mongo item base class.
+
+    Note: only MongoFieldProperty attributes get observed and updated by our
+    transaction handling. If you change other attributes, you have to set
+    _m_changed to True by yourself.
+
+    Note: We do not support manipulators known from pymongo. We use a converter
+    pattern for ding the convertion, see converters
+    """
+
+    # built in attrs
+    _type = None
+    __m_changed = None
+
+    # built in skip and dump names
+    _skipNames = []
+    _dumpNames = ['_type', '__name__', 'created', 'modified']
+
+    # attrs with default values
+    created = MongoFieldProperty(interfaces.IMongoSubObject['created'])
+    modified = MongoFieldProperty(interfaces.IMongoSubObject['modified'])
+
+    def __init__(self, data):
+        """Initialize a mongo item with given data.
+
+        This method will also make sure that the __parent__ and other values
+        get set before we call setup.
+
+        Note: if you enhance your own MongoItem __init__ method, don't forget
+        to set_m_changed to None. Otherwise it will end in write access on
+        each read.
+        """
+        # set given or None __name__ and __parent__
+        self.__name__ = data.pop('__name__', None)
+        self.__parent__ = data.pop('__parent__', None)
+        # set given or new _type if not already set as built-in
+        if self._type is None:
+            _type = data.pop('_type', self.__class__.__name__)
+            if _type != self.__class__.__name__:
+                raise TypeError("Wrong mongo item _type used")
+            self.__dict__['_type'] = unicode(_type)
+        # set given or new created datetime
+        created = data.pop('created', _marker)
+        if created is _marker:
+            created = datetime.datetime.now(UTC)
+        self.__dict__['created'] = created
+        # setup object with given (non IMongoItem) key/value data
+        self.setup(data)
+        # it is very important to set _m_changed to None, otherwise each read
+        # access will end in a write access.
+        self._m_changed = None
+
+    @apply
+    def _m_changed():
+        def get(self):
+            return self.__m_changed
+        def set(self, value):
+            self.__m_changed = value
+            if self.__parent__ is not None and value == True:
+                self.__parent__._m_changed = True
+        return property(get, set)
+
+
 class MongoMappingBase(MongoItemAware, zope.location.location.Location):
     """Mongo mapping base class with thread save transaction and caching
     support.
