@@ -33,9 +33,15 @@ class IMongoList(zope.schema.interfaces.IList):
     Python list used in mogo item list.
     """
 
+
+class IMongoSubObjectConverter(zope.schema.interfaces.IObject):
+    """Mongo object converter field"""
+
+
 class IMongoBinary(zope.schema.interfaces.IBytes):
     """Field which stores bson.binary.Binary data"""
 
+
 class IMongoDate(zope.schema.interfaces.IDate):
     """Field which stores an ordinal integer as date."""
 
@@ -442,6 +448,42 @@ class IMongoItem(ISetup, IConvert, IDump, ICreatedModified):
         marker for track file system references in m01.mongofs.
         """
 
+class IMongoSubObject(ISetup, IConvert, IDump, ICreatedModified):
+    """Mongo item base class.
+
+    Note: only MongoFieldProperty attributes get observed and updated by our
+    transaction handling. If you change other attributes, you have to set
+    _m_changed to True by yourself.
+
+    Note: We do not support manipulators known from pymongo. We use a converter
+    pattern for ding the convertion, see converters
+    """
+
+    _m_changed = zope.interface.Attribute(
+        """The persistent state of the object.
+
+        This is one of:
+
+        None -- The object is loaded from the MongoDB
+
+        False -- The obj get updated within the update method and set the False
+
+        True -- The object has been modified since it was last saved
+
+        """)
+
+    _type = zope.schema.TextLine(
+        title=u'Type',
+        description=u'Mongo item type',
+        default=None,
+        required=True)
+
+    _version = zope.schema.Int(
+        title=u'Version',
+        description=u'Mongo item version',
+        default=0,
+        required=True)
+
 
 class IMongoStorageItem(IMongoItem):
     """Mongo storage item."""
