@@ -5,7 +5,7 @@
 #
 ##############################################################################
 """Settings
-$Id: settings.py 4730 2018-02-04 12:51:52Z roger.ineichen $
+$Id: settings.py 5071 2021-01-14 08:17:22Z roger.ineichen $
 """
 __docformat__ = "reStructuredText"
 
@@ -53,9 +53,20 @@ MONGODB_SSL_CERT_REQUIRED = None
 MONGODB_SSL_MATCH_HOSTNAME = True
 MONGODB_CA_CERT = None
 MONGODB_CLIENT_CERT = None
+MONGODB_CLIENT_CERT_KEY_FILE = None
 MONGODB_PEM_PASSPHRASE = None
 MONGODB_REVOCATION_LIST = None
 
+# tls options
+MONGODB_TLS = False
+MONGODB_TLS_CA_FILE = None
+MONGODB_TLS_CERT_KEY_FILE = None
+MONGODB_TLS_CERT_KEY_FILE_PASSWORD = None
+MONGODB_TLS_CRL_FILE = None
+MONGODB_TLS_ALLOW_INVALID_CERT = False
+MONGODB_TLS_ALLOW_INVALID_HOSTNAME = False
+MONGODB_TLS_CERTIFICATE_SELECTOR = None
+
 # auth options
 MONGODB_AUTH_MECHNISM = None
 MONGODB_USERNAME = None
@@ -93,7 +104,7 @@ MONGODB_HEARTBEAT_FREQUENCY = p01.env.getEnviron(
     'MONGODB_HEARTBEAT_FREQUENCY', rType=int,
     default=MONGODB_HEARTBEAT_FREQUENCY)
 MONGODB_WAIT_QUEUE_MULTIPLE = p01.env.getEnviron('MONGODB_WAIT_QUEUE_MULTIPLE',
-    default=MONGODB_WAIT_QUEUE_MULTIPLE)
+    rType=int, default=MONGODB_WAIT_QUEUE_MULTIPLE)
 
 # ssl options
 MONGODB_SSL = p01.env.getEnviron('MONGODB_SSL', rType=bool,
@@ -107,12 +118,36 @@ MONGODB_CA_CERT = p01.env.getEnviron('MONGODB_CA_CERT',
     rType='path', default=MONGODB_CA_CERT)
 MONGODB_CLIENT_CERT = p01.env.getEnviron('MONGODB_CLIENT_CERT',
     rType='path', default=MONGODB_CLIENT_CERT)
+MONGODB_CLIENT_CERT_KEY_FILE= p01.env.getEnviron('MONGODB_CLIENT_CERT_KEY_FILE',
+    rType='path', default=MONGODB_CLIENT_CERT_KEY_FILE)
 MONGODB_PEM_PASSPHRASE = p01.env.getEnviron('MONGODB_PEM_PASSPHRASE',
     default=MONGODB_PEM_PASSPHRASE)
 MONGODB_REVOCATION_LIST = p01.env.getEnviron(
     'MONGODB_REVOCATION_LIST', rType='path',
     default=MONGODB_REVOCATION_LIST)
 
+# tls options
+MONGODB_TLS = p01.env.getEnviron('MONGODB_TLS', rType=bool,
+    default=MONGODB_TLS)
+MONGODB_TLS_CA_FILE = p01.env.getEnviron('MONGODB_TLS_CA_FILE',
+    rType='path', default=MONGODB_TLS_CA_FILE)
+MONGODB_TLS_CERT_KEY_FILE = p01.env.getEnviron('MONGODB_TLS_CERT_KEY_FILE',
+    rType='path', default=MONGODB_TLS_CERT_KEY_FILE)
+MONGODB_TLS_CERT_KEY_FILE_PASSWORD = p01.env.getEnviron(
+    'MONGODB_TLS_CERT_KEY_FILE_PASSWORD',
+    default=MONGODB_TLS_CERT_KEY_FILE_PASSWORD)
+MONGODB_TLS_CRL_FILE = p01.env.getEnviron('MONGODB_TLS_CRL_FILE',
+    rType='path', default=MONGODB_TLS_CRL_FILE)
+MONGODB_TLS_ALLOW_INVALID_CERT = p01.env.getEnviron(
+    'MONGODB_TLS_ALLOW_INVALID_CERT', rType=bool,
+    default=MONGODB_TLS_ALLOW_INVALID_CERT)
+MONGODB_TLS_ALLOW_INVALID_HOSTNAME = p01.env.getEnviron(
+    'MONGODB_TLS_ALLOW_INVALID_HOSTNAME', rType=bool,
+    default=MONGODB_TLS_ALLOW_INVALID_HOSTNAME)
+MONGODB_TLS_CERTIFICATE_SELECTOR = p01.env.getEnviron(
+    'MONGODB_TLS_ALLOW_INVALID_HOSTNAME', rType=str,
+    default=MONGODB_TLS_ALLOW_INVALID_HOSTNAME)
+
 # auth options
 MONGODB_AUTH_MECHNISM = p01.env.getEnviron('MONGODB_AUTH_MECHNISM',
     default=MONGODB_AUTH_MECHNISM)
@@ -122,6 +157,9 @@ MONGODB_PASSWORD = p01.env.getEnviron('MONGODB_PASSWORD',
     default=MONGODB_PASSWORD)
 
 
-# support p01.cdn extraction
+# support p01.cdn extraction marker
 P01_CDN_RECIPE_PROCESS = p01.env.getEnviron('P01_CDN_RECIPE_PROCESS',
-    default=False)
\ No newline at end of file
+    default=False)
+
+# support i18n extraction marker
+I18N_EXTRACT = p01.env.getEnviron('I18N_EXTRACT', default=False)
